@@ -1,13 +1,11 @@
 use strict;
 use warnings;
 package WWW::IP;
-$WWW::IP::VERSION = '0.02';
+$WWW::IP::VERSION = '0.03';
 use HTTP::Tiny;
 use 5.008;
 use WWW::hmaip ();
-use WWW::PerlTricksIP ();
 use WWW::ipinfo ();
-use Try::Tiny;
 
 # ABSTRACT: Returns your ip address with failsafe mechanism
 
@@ -21,20 +19,12 @@ BEGIN {
 
 
 sub get_ip {
-  try {
-    WWW::hmaip::get_ip();
-  } catch {
-    try {
-      WWW::ipinfo::get_ipinfo->{ip};
-    } catch {
-      try {
-        WWW::PerlTricksIP::get_ip();
-      }
-      catch {
-        die $_;
-      }
-    }
-  };
+  my $ip = eval { WWW::hmaip::get_ip() };
+  if ($@)
+  {
+    $ip = WWW::ipinfo::get_ipinfo->{ip};
+  }
+  return $ip;
 }
 
 
@@ -52,7 +42,7 @@ WWW::IP - Returns your ip address with failsafe mechanism
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -88,10 +78,6 @@ L<WWW::ipinfo> - a module that returns ip address and geolocation data
 
 L<WWW::hmaip> - another module that returns your ip address
 
-=item *
-
-L<WWW::PerlTricksIP> - another module that returns your ip address
-
 =back
 
 =head1 AUTHOR
